@@ -2,6 +2,7 @@
     Kodexa is a Python framework to enable flexible data engineering with semi-structured and unstructured documents and
     data.
 """
+from .assistant import Assistant, AssistantContext
 from .cloud import RemoteSession, RemotePipeline, RemoteAction, KodexaPlatform
 from .connectors import FolderConnector, FileHandleConnector, UrlConnector, registered_connectors, get_connectors, \
     get_connector, add_connector, get_source
@@ -10,10 +11,8 @@ from .model import DocumentMetadata, ContentNode, ContentFeature, SourceMetadata
     Document, RemoteStore, DocumentStore
 from .pipeline import Pipeline, PipelineStatistics, PipelineContext
 from .sinks import InMemoryDocumentSink, FolderSink
-from .steps import NodeTagger, NodeTagCopy, TextParser, RollupTransformer, TagsToKeyValuePairExtractor, \
-    KodexaProcessingException
-from .stores import JsonDocumentStore, TableDataStore, DictDataStore, DataStoreHelper, LocalDocumentStore, \
+from .steps import NodeTagger, NodeTagCopy, TextParser, RollupTransformer, TagsToKeyValuePairExtractor
+from .stores import TableDataStore, DataStoreHelper, LocalDocumentStore, \
     RemoteDocumentStore, RemoteTableDataStore, RemoteDictDataStore, RemoteModelStore, LocalModelStore
 from .taxonomy import Taxonomy, Taxon, RemoteTaxonomy
 from .workflow import Workflow, CronSchedule, WebSchedule, StorePublisher
-from .assistant import Assistant
\ No newline at end of file
