@@ -31,6 +31,11 @@ dirs = AppDirs("Kodexa", "Kodexa")
 
 
 def get_config():
+    """
+    Get the kodexa config object we use when you want to store your PAT locally
+
+    :return: the config as a dict
+    """
     path = os.path.join(dirs.user_config_dir, '.kodexa.json')
     if os.path.exists(path):
         with open(path, 'r') as outfile:
@@ -40,6 +45,12 @@ def get_config():
 
 
 def save_config(config_obj):
+    """
+    Saves the configuration dictionary for the user
+
+    :param config_obj:
+    :return:
+    """
     path = os.path.join(dirs.user_config_dir, '.kodexa.json')
     if not os.path.exists(os.path.dirname(path)):
         try:
@@ -115,6 +126,7 @@ DEFAULT_COLUMNS = {
     ]
 }
 
+
 OBJECT_TYPES = {
     "extensionPacks": {
         "name": "extension pack",
@@ -152,6 +164,12 @@ OBJECT_TYPES = {
 
 
 def resolve_object_type(obj_type):
+    """
+    Takes part of an object type (ie. pipelin) and then resolves the object type (pipelines)
+
+    :param obj_type: part of the object type
+    :return: The object type dict (if found)
+    """
     hits = []
     keys = []
     for target_type in OBJECT_TYPES.keys():
@@ -171,6 +189,11 @@ def resolve_object_type(obj_type):
 
 
 class KodexaPlatform:
+    """
+    The KodexaPlatform object allows you to work with an instance of the Kodexa platform, allow you to list, view and deploy
+    components
+
+    """
 
     @staticmethod
     def get_access_token():
@@ -363,19 +386,6 @@ class KodexaPlatform:
             metadata_object.description = 'A new assistant definition' if metadata_object.description is None else metadata_object.description
             object_url = 'assistants'
             metadata_object.type = 'assistant'
-            metadata_object.fullDescription = kodexa_object.full_description
-            metadata_object.workflows = jsonpickle.decode(jsonpickle.encode(kodexa_object.workflows, unpicklable=False))
-            metadata_object.requiredStores = jsonpickle.decode(
-                jsonpickle.encode(kodexa_object.required_stores, unpicklable=False))
-            metadata_object.processingTaxonomies = jsonpickle.decode(
-                jsonpickle.encode(kodexa_object.processing_taxonomies, unpicklable=False))
-
-            # For our services we are actually going to dry run each of these
-            # as deploys to create the correct objects
-
-            metadata_object.services = []
-            for service in kodexa_object.services:
-                metadata_object.services.append(KodexaPlatform.deploy(f'./{service.slug}', service, dry_run=True))
 
         else:
             raise Exception("Unknown object type, unable to deploy")
@@ -706,7 +716,7 @@ class RemoteSession:
             headers={"x-access-token": KodexaPlatform.get_access_token()})
         logger.debug(f"Response from server [{response.text}]")
         raw_store = Dict(json.loads(response.text))
-        return TableDataStore(raw_store.data.columns, raw_store.data.rows, raw_store.data.source_documents)
+        return TableDataStore(raw_store.data.columns, raw_store.data.rows)
 
     def merge_stores(self, execution, context: PipelineContext):
         for store in execution.stores:
