@@ -261,7 +261,7 @@ class DocumentStoreConnector(object):
         if self.index >= self.store.count():
             raise StopIteration
         else:
-            uuid_value = self.store.list_objects()[self.index]['uuid']
+            uuid_value = self.store.list_objects()[self.index].id
             self.index += 1
             return self.store.get_by_uuid(uuid_value)
 
