@@ -1,8 +1,4 @@
 """
-Extractors
-----------
-
 Extractors are a way to build structured datasets that you can use from tags within Documents
-
 """
 from .extractors import TaggedTableToDataStore
